/*
 * (C) 1995-2001 Clemson University and Argonne National Laboratory.
 *
 * See COPYING in top-level directory.
 */


static char pvfs_access_c[] = "$Header: /projects/cvsroot/pvfs/lib/pvfs_access.c,v 1.7 2001/05/24 03:08:40 rbross Exp $";

/* This file contains PVFS library call for access.   		*/
/* It will determine if file is UNIX or PVFS and then 		*/
/* make the proper request.					*/

#include <lib.h>
#include <meta.h>

extern int errno;
extern int pvfs_checks_disabled;

int unix_access(char *path, int mode);

int pvfs_access(char* pathname, int mode)
{
	int i=0, s;
	mack ack;
	mreq request;
	struct sockaddr *saddr;
	char *fn;
	int64_t fs_ino;

	if (!pathname) {
		errno = EFAULT;
		return(-1);
	}

	if (pvfs_checks_disabled ||
		(i = pvfs_detect(pathname, &fn, &saddr, &fs_ino)) < 1) {
		if (i < 0) {
			PERROR("Error finding file");
			return(-1);
		}	
		return access(pathname, mode);
	}

	/* Prepare request for file system  */
	request.dsize = strlen(fn);
	request.uid = getuid();
	request.gid = getgid();
	request.type = MGR_ACCESS;
	request.req.access.fname = 0;
	request.req.access.mode = mode;

	/* Send request to mgr */
	if ((s = send_mreq_saddr(saddr, &request, fn, &ack)) < 0) {
		PERROR("send_mreq");
		return(-1);
	}
	return(0);
}
